#content{position:relative;z-index:1}#container{height:auto;min-height:100%}#main{z-index:1}#header{z-index:2}.calendarbox,.clockbox{z-index:1}#nav-sidebar{top:var(--djai-nav-sidebar-offset)}#header{overflow:visible;position:sticky;top:0}:root{--djai-tab-bg:#4383a3;--djai-tab-bg--active:var(--primary,#79aec8);--djai-tab-bg--hover:var(--primary,#79aec8);--djai-tab-fg:var(--primary-fg,#fff);--djai-tab-fg--active:var(--primary-fg,#fff);--djai-tab-fg--hover:var(--primary-fg,#fff);--djai-dropdown-bg:var(--secondary,#417690);--djai-dropdown-bg--active:var(--primary,#79aec8);--djai-dropdown-bg--hover:var(--primary,#79aec8);--djai-dropdown-fg:var(--header-link-color,var(--primary-fg,#fff));--djai-tablist-spacing-top:10px;--djai-nav-sidebar-offset:84px}.djai-dropdown-menu{display:block;flex-basis:100%;margin-top:var(--djai-tablist-spacing-top)}#header{flex-wrap:wrap;padding-bottom:0}.djai-dropdown-menu .djai-dropdown-menu__item{background-color:var(--djai-tab-bg);cursor:pointer;display:inline-block;padding:10px;position:relative}.djai-dropdown-menu .djai-dropdown-menu__item,.djai-dropdown-menu .djai-dropdown-menu__item:link,.djai-dropdown-menu .djai-dropdown-menu__item:visited{color:var(--djai-tab-fg)}.djai-dropdown-menu .djai-dropdown-menu__item--active{background-color:var(--djai-tab-bg--active)}.djai-dropdown-menu .djai-dropdown-menu__item--active,.djai-dropdown-menu .djai-dropdown-menu__item--active:link,.djai-dropdown-menu .djai-dropdown-menu__item--active:visited{color:var(--djai-tab-fg--active);text-decoration:none}.djai-dropdown-menu .djai-dropdown-menu__item:focus,.djai-dropdown-menu .djai-dropdown-menu__item:hover{background-color:var(--djai-tab-bg--hover)}.djai-dropdown-menu .djai-dropdown-menu__item:focus,.djai-dropdown-menu .djai-dropdown-menu__item:focus:link,.djai-dropdown-menu .djai-dropdown-menu__item:focus:visited,.djai-dropdown-menu .djai-dropdown-menu__item:hover,.djai-dropdown-menu .djai-dropdown-menu__item:hover:link,.djai-dropdown-menu .djai-dropdown-menu__item:hover:visited{color:var(--djai-tab-fg--hover);text-decoration:none!important}.djai-dropdown-menu .djai-dropdown-menu__item:focus .djai-dropdown-menu__drop,.djai-dropdown-menu .djai-dropdown-menu__item:hover .djai-dropdown-menu__drop{display:block}.djai-dropdown-menu .djai-dropdown-menu__drop{background-color:var(--djai-dropdown-bg);box-shadow:0 4px 8px 0 rgba(0,0,0,.2),0 6px 20px 0 rgba(0,0,0,.2);display:none;left:0;max-height:75vh;min-width:150px;overflow-y:auto;position:absolute;top:100%;z-index:1}.djai-dropdown-menu .djai-dropdown-menu__drop-item{background-color:transparent}.djai-dropdown-menu .djai-dropdown-menu__drop-item--active{background-color:var(--djai-dropdown-bg--active)}.djai-dropdown-menu .djai-dropdown-menu__drop-item:focus,.djai-dropdown-menu .djai-dropdown-menu__drop-item:hover{background-color:var(--djai-dropdown-bg--hover)}#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a,#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a:link,#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a:visited{color:var(--djai-dropdown-fg)}#header .djai-dropdown-menu .djai-dropdown-menu__drop-item a:hover{text-decoration:none}.djai-dropdown-menu .djai-dropdown-menu__link{display:block;padding:10px}@media (max-width:767px){.breadcrumbs{position:relative;z-index:1}.djai-dropdown-menu{align-self:flex-start}.djai-dropdown-menu .djai-dropdown-menu__item{margin-top:3px}}
/*# sourceMappingURL=admin-index.css.map */
