# :copyright: (c) 2017, Maykin Media BV.
#             All rights reserved.
# :license:   BSD (3 Clause), see LICENSE for more details.
__version__ = "2.0.2"
__author__ = "Joeri Bekker"

default_app_config = "django_admin_index.apps.AdminIndexConfig"
